/// <reference types="react" />
import type { NavigateOptions } from './history';
import { flattenSearchParams } from './util';
type FlattenSearchParams = ReturnType<typeof flattenSearchParams>;
type UseMatchOptions = {
    searchParams?: FlattenSearchParams;
    matchSubPaths?: boolean;
};
/**
 * Returns an object of { match: boolean; params: Record<string, unknown>; }
 * if the path matches the current location match will be true.
 * Params will be an object of the matched params, if there are any.
 *
 * Provide searchParams options to match the current location.search
 *
 * This is useful for components that need to know "active" state, e.g.
 * <NavLink>.
 *
 * Examples:
 *
 * Match search params key existence
 * const match = useMatch('/about', { searchParams: ['category', 'page'] })
 *
 * Match search params key and value
 * const match = useMatch('/items', { searchParams: [{page: 2}, {category: 'book'}] })
 *
 * Mix match
 * const match = useMatch('/list', { searchParams: [{page: 2}, 'gtm'] })
 *
 * Match sub paths
 * const match = useMatch('/product', { matchSubPaths: true })
 *
 */
declare const useMatch: (pathname: string, options?: UseMatchOptions) => {
    match: boolean;
    params: Record<string, unknown>;
} | {
    match: boolean;
};
interface LinkProps {
    to: string;
    onClick?: React.MouseEventHandler<HTMLAnchorElement>;
}
declare const Link: import("react").ForwardRefExoticComponent<LinkProps & import("react").AnchorHTMLAttributes<HTMLAnchorElement> & import("react").RefAttributes<HTMLAnchorElement>>;
interface NavLinkProps {
    to: string;
    activeClassName: string;
    activeMatchParams?: FlattenSearchParams;
    matchSubPaths?: boolean;
    onClick?: React.MouseEventHandler<HTMLAnchorElement>;
}
declare const NavLink: import("react").ForwardRefExoticComponent<NavLinkProps & import("react").AnchorHTMLAttributes<HTMLAnchorElement> & import("react").RefAttributes<HTMLAnchorElement>>;
interface RedirectProps {
    /** The path to redirect to */
    to: string;
    options?: NavigateOptions;
}
/**
 * A declarative way to redirect to a route name
 */
declare const Redirect: ({ to, options }: RedirectProps) => null;
export { Link, NavLink, useMatch, Redirect };
//# sourceMappingURL=links.d.ts.map